/*===========================================================================*/
/*
 * This file is part of
 * libalinga - a C++ library for Alligned Linguistic Annotation
 *
 * Copyright (C) 2007, 2008, 2009-2014 Elaine Tsiang YueLien
 *
 * libalinga is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public
 * License as published by the Free Software Foundation; either
 * version 3 of the License, or (at your option) any later version.
 * 
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public
 * License along with this library; if not, see http://www.gnu.org/licenses, or write to the
 * Free Software Foundation, Inc.
 * 51 Franklin Street, Fifth Floor
 * Boston, MA  02110-1301, USA
 *
 *===========================================================================*/
/** @file MetasImpl.C                                                        *
 *                                                                           *
 *  ALingA::MetasImpl - Metas implementation                                 *
 *                                                                           */
/*===========================================================================*/
#ifdef __GNUG__
#pragma implementation "Metas.H"
#pragma implementation "MetasImpl.H"
#endif

#include	<MetasImpl.H>

namespace	ALingA
{
  MetasXMLparser::MetasXMLparser(
				 ALingA::XMLparser &	parent
				 ,Metas &		metas
				 )
    : ALingA::XMLparser("Metas"
			,&parent
			)
  {
    MetasXMLparserImpl * impl = new MetasXMLparserImpl(
						       metas
						       );

    impl->intf_ = this;
    impl_ = impl;
  }

  MetasXMLparserImpl::MetasXMLparserImpl(
					 Metas &			metas
					 )
    : metas_(metas)
    , imetas_(metas.end())
  {
  }

  MetasXMLparser::~MetasXMLparser()
  {
    if ( impl_ )
      {
	MetasXMLparserImpl * impl = static_cast<MetasXMLparserImpl *>(impl_);
	
	delete impl;
	impl_ = 0;
      }
  }

  void
  MetasXMLparser::on_start_element(
				   const Glib::ustring& 	name
				   , const xmlpp::SaxParser::AttributeList& attributes
				   )
  {
    MetasXMLparserImpl * impl = static_cast<MetasXMLparserImpl *>(impl_);

    if ( name == "Meta" )
      {
	if ( attributes.empty()
	     ||
	     ( attributes.begin()->name != "name" )
	     )
	  throw XMLparser::UnexpectedAttribute(attributes.begin()->name);
	
	impl->metas_[attributes.begin()->value] = "";

	impl->imetas_ = impl->metas_.find(attributes.begin()->value);

	new MetaXMLparser(*this
			  , impl->metas_
			  , impl->imetas_
			  );
      }
    else
      throw XMLparser::UnexpectedElement(name);
  }
}
